Module led

Module led 

led module controls the LED on the TKey.

Constants

LED_BLUE
LED_CYAN
LED_GREEN
LED_OFF
LED_PURPLE
LED_RED
LED_WHITE
LED_YELLOW
TK1_LED
TK1_LED is the address for controlling the LED.
TK1_LED_BIT_BLUE
TK1_LED_BIT_BLUE is the bit (index) that controls the blue led.
TK1_LED_BIT_GREEN
TK1_LED_BIT_GREEN is the bit (index) that controls the green led.
TK1_LED_BIT_RED
TK1_LED_BIT_RED is the bit (index) that controls the red led.

Functions

change
change sets the LED to a new color and returns the previous color.
get
get gets the current LED value.
set
set sets the LED value.
signal
signal performs count flashes uniformly between two LED-colors: color1 and color2. Afterwards, the previous LED color is restored. Blinking the LED with alternating colors, is a simple but effective way to signal a user that is physically near the TKey device.