read_bytes_next

Function read_bytes_next 

pub fn read_bytes_next() -> [u8; 4]
read_bytes_next waits for the TRNG to become ready then reads the available entropy from the entropy source.

Entropy is produced at a rate of approximately 66.6 times per second.