led module controls the LED on the TKey.
Constants
- LED_
BLUE - LED_
CYAN - LED_
GREEN - LED_OFF
- LED_
PURPLE - LED_RED
- LED_
WHITE - LED_
YELLOW - TK1_LED
TK1_LEDis the address for controlling the LED.- TK1_
LED_ BIT_ BLUE TK1_LED_BIT_BLUEis the bit (index) that controls the blue led.- TK1_
LED_ BIT_ GREEN TK1_LED_BIT_GREENis the bit (index) that controls the green led.- TK1_
LED_ BIT_ RED TK1_LED_BIT_REDis the bit (index) that controls the red led.
Functions
- change
changesets the LED to a new color and returns the previous color.- get
getgets the current LED value.- set
setsets the LED value.- signal
signalperformscountflashes uniformly between two LED-colors:color1andcolor2. Afterwards, the previous LED color is restored. Blinking the LED with alternating colors, is a simple but effective way to signal a user that is physically near the TKey device.